==> rdg-corp-rdg-blocks-1.3.11-820347.zip: blocks/rdg-title/main.php <==
<?php

// Exit if accessed directly.
if (!defined('ABSPATH')) exit;

class Rdg_Blocks_Title extends Rdg_Blocks_Base
{
    protected $block_name = BLOCK_RDG_TITLE;
    private $block_folder_name = 'rdg-title';
    protected $block_title = 'RDG Title';
    private $block_description = '';
    private $block_icon = 'admin-links';
    private $block_keywords = ['rdg', 'custom', 'title'];
    private $block_mode = 'preview';
    private $block_category = RDGBLOCKS_NAME_SLUG;
    protected $is_caching = false;
    protected $is_config = false;
    protected $is_styles_load = false;
    protected $is_pre_saved = false;

    public function init() {
        $this->register_block();
    }

    private function register_block() {
        if (function_exists('acf_register_block_type')) {
            $rdg_helpers = new Rdg_Blocks_Helpers();
            acf_register_block_type([
                'name' => $this->block_name,
                'title' => __($this->block_title),
                'description' => __($this->block_description),
                'category' => $this->block_category,
                'icon' => $this->block_icon,
                'keywords' => $this->block_keywords,
                'mode' => $this->block_mode,
                'render_template' => RDGBLOCKS_PLUGIN_DIR . "/blocks/".$this->block_folder_name."/template.php",
                'enqueue_style' => $rdg_helpers->webpack('rdg_title.css'),
                'supports' => [
                    'jsx' => true,
			        'color' => [
                        'background' => true,
                        'gradients'  => false,
                        'text' => false,
                    ],
                ],
            ]);
        }
    }

    // public function getColorsToloadGeneratePress() {
    //     return [];
    // }

    // public function getStylesToloadGeneratePress() {
    //     return [];
    // }
}

$rdg_title_class = new Rdg_Blocks_Title();
$rdg_title_class->init();

return $rdg_title_class;

==> rdg-corp-rdg-blocks-1.3.111-277194.zip: blocks/rdg-title/main.php <==
<?php

// Exit if accessed directly.
if (!defined('ABSPATH')) exit;

class Rdg_Blocks_Title extends Rdg_Blocks_Base
{
    protected $block_name = BLOCK_RDG_TITLE;
    private $block_folder_name = 'rdg-title';
    protected $block_title = 'RDG Title';
    private $block_description = 'This block is the style for all the titles used by RDG-Blocks';
    private $block_icon = 'admin-links';
    private $block_keywords = ['rdg', 'custom', 'title'];
    private $block_mode = 'preview';
    private $block_category = RDGBLOCKS_NAME_SLUG;

    public function init() {
        $this->register_block();
    }

    private function register_block() {
        if (function_exists('acf_register_block_type')) {
            $rdg_helpers = new Rdg_Blocks_Helpers();
            acf_register_block_type([
                'name' => $this->block_name,
                'title' => __($this->block_title),
                'description' => __($this->block_description),
                'category' => $this->block_category,
                'icon' => $this->block_icon,
                'keywords' => $this->block_keywords,
                'mode' => $this->block_mode,
                'render_template' => RDGBLOCKS_PLUGIN_DIR . "/blocks/".$this->block_folder_name."/template.php",
                'enqueue_style' => $rdg_helpers->webpack('rdg_title.css'),
                'example' => array(
                    'attributes' => array(
                        'mode' => 'preview',
                        'data' => array(
                            'isExample' => true,
                            'preview_image' => RDGBLOCKS_PLUGIN_URL."dist/images/rdg-title-template-preview.jpg",
                        ),
                    ),
                ),
                'supports' => [
                    'jsx' => true,
			        'color' => [
                        'background' => true,
                        'gradients'  => false,
                        'text' => false,
                    ],
                ],
            ]);
        }
    }

    // public function getColorsToloadGeneratePress() {
    //     return [];
    // }

    // public function getStylesToloadGeneratePress() {
    //     return [];
    // }
}

$rdg_title_class = new Rdg_Blocks_Title();
$rdg_title_class->init();

return $rdg_title_class;
